==> plasma-workspace-5.9.4.tar.xz: plasma-workspace-5.9.4/plasmawayland.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Exec=dbus-launch --exit-with-session ${CMAKE_INSTALL_FULL_BINDIR}/startplasmacompositor
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/startplasmacompositor
DesktopNames=KDE
Name=Plasma
Name[ar]=بلازما
Name[bs]=Plazma
Name[ca]=Plasma
Name[ca@valencia]=Plasma
Name[cs]=Plasma
Name[da]=Plasma
Name[de]=Plasma
Name[el]=Plasma
Name[en_GB]=Plasma
Name[es]=Plasma
Name[et]=Plasma
Name[eu]=Plasma
Name[fi]=Plasma
Name[fr]=Plasma
Name[gl]=Plasma
Name[he]=פלזמה
Name[hu]=Plasma
Name[id]=Plasma
Name[is]=Plasma
Name[it]=Plasma
Name[ja]=プラズマ
Name[ko]=Plasma
Name[lt]=Plasma
Name[nb]=Plasma
Name[nds]=Plasma
Name[nl]=Plasma
Name[nn]=Plasma
Name[pa]=ਪਲਾਜ਼ਮਾ
Name[pl]=Plazma
Name[pt]=Plasma
Name[pt_BR]=Plasma
Name[ru]=Plasma
Name[sk]=Plasma
Name[sl]=Plasma
Name[sr]=Плазма
Name[sr@ijekavian]=Плазма
Name[sr@ijekavianlatin]=Plasma
Name[sr@latin]=Plasma
Name[sv]=Plasma
Name[tr]=Plazma
Name[uk]=Плазма
Name[x-test]=xxPlasmaxx
Name[zh_CN]=Plasma
Name[zh_TW]=Plasma
Comment=Plasma by KDE
Comment[ar]=بلازما كدي
Comment[bs]=Plazma od strane KDe
Comment[ca]=Plasma creat per la comunitat KDE
Comment[ca@valencia]=Plasma creat per la comunitat KDE
Comment[cs]=Plasma z KDE
Comment[da]=Plasma fra KDE
Comment[de]=Plasma von KDE
Comment[el]=Plasma από το KDE
Comment[en_GB]=Plasma by KDE
Comment[es]=Plasma, por KDE
Comment[et]=KDE Plasma
Comment[eu]=KDEren Plasma
Comment[fi]=Plasma KDE:ltä
Comment[fr]=Plasma, par KDE
Comment[gl]=Plasma por KDE
Comment[he]=פלזמה באמצעות KDE
Comment[hu]=Plasma a KDE-től
Comment[id]=Plasma oleh KDE
Comment[is]=Plasma frá KDE
Comment[it]=Plasma di KDE
Comment[ja]=Plasma by KDE
Comment[ko]=KDE Plasma
Comment[lt]=Plasmą sukūrė KDE
Comment[nb]=Plasma av KDE
Comment[nds]=Plasma vun KDE
Comment[nl]=Plasma door KDE
Comment[nn]=Plasma frå KDE
Comment[pa]=KDE ਵਲੋਂ ਪਲਾਜ਼ਮਾ
Comment[pl]=Plazma dzięki KDE
Comment[pt]=Plasma do KDE
Comment[pt_BR]=Plasma do KDE
Comment[ru]=KDE Plasma
Comment[sk]=Plasma od KDE
Comment[sl]=KDE Plasma
Comment[sr]=Плазма од КДЕ‑а
Comment[sr@ijekavian]=Плазма од КДЕ‑а
Comment[sr@ijekavianlatin]=Plasma od KDE‑a
Comment[sr@latin]=Plasma od KDE‑a
Comment[sv]=Plasma av KDE
Comment[tr]=KDE Plazması
Comment[uk]=Плазма KDE
Comment[x-test]=xxPlasma by KDExx
Comment[zh_CN]=KDE 的 Plasma
Comment[zh_TW]=Plasma by KDE
X-KDE-PluginInfo-Version=${PROJECT_VERSION}

==> plasma-workspace-5.10.3.tar.xz: plasma-workspace-5.10.3/plasmawayland.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Exec=dbus-launch --exit-with-session ${CMAKE_INSTALL_FULL_BINDIR}/startplasmacompositor
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/startplasmacompositor
DesktopNames=KDE
Name=Plasma
Name[ar]=بلازما
Name[bs]=Plazma
Name[ca]=Plasma
Name[ca@valencia]=Plasma
Name[cs]=Plasma
Name[da]=Plasma
Name[de]=Plasma
Name[el]=Plasma
Name[en_GB]=Plasma
Name[es]=Plasma
Name[et]=Plasma
Name[eu]=Plasma
Name[fi]=Plasma
Name[fr]=Plasma
Name[gl]=Plasma
Name[he]=פלזמה
Name[hu]=Plasma
Name[id]=Plasma
Name[is]=Plasma
Name[it]=Plasma
Name[ja]=プラズマ
Name[ko]=Plasma
Name[lt]=Plasma
Name[nb]=Plasma
Name[nds]=Plasma
Name[nl]=Plasma
Name[nn]=Plasma
Name[pa]=ਪਲਾਜ਼ਮਾ
Name[pl]=Plazma
Name[pt]=Plasma
Name[pt_BR]=Plasma
Name[ru]=Plasma
Name[sk]=Plasma
Name[sl]=Plasma
Name[sr]=Плазма
Name[sr@ijekavian]=Плазма
Name[sr@ijekavianlatin]=Plasma
Name[sr@latin]=Plasma
Name[sv]=Plasma
Name[tr]=Plama
Name[uk]=Плазма
Name[x-test]=xxPlasmaxx
Name[zh_CN]=Plasma
Name[zh_TW]=Plasma
Comment=Plasma by KDE
Comment[ar]=بلازما كدي
Comment[bs]=Plazma od strane KDe
Comment[ca]=Plasma creat per la comunitat KDE
Comment[ca@valencia]=Plasma creat per la comunitat KDE
Comment[cs]=Plasma z KDE
Comment[da]=Plasma fra KDE
Comment[de]=Plasma von KDE
Comment[el]=Plasma από το KDE
Comment[en_GB]=Plasma by KDE
Comment[es]=Plasma, por KDE
Comment[et]=KDE Plasma
Comment[eu]=KDEren Plasma
Comment[fi]=Plasma KDE:ltä
Comment[fr]=Plasma, par KDE
Comment[gl]=Plasma por KDE
Comment[he]=פלזמה באמצעות KDE
Comment[hu]=Plasma a KDE-től
Comment[id]=Plasma oleh KDE
Comment[is]=Plasma frá KDE
Comment[it]=Plasma di KDE
Comment[ja]=Plasma by KDE
Comment[ko]=KDE Plasma
Comment[lt]=Plasmą sukūrė KDE
Comment[nb]=Plasma av KDE
Comment[nds]=Plasma vun KDE
Comment[nl]=Plasma door KDE
Comment[nn]=Plasma frå KDE
Comment[pa]=KDE ਵਲੋਂ ਪਲਾਜ਼ਮਾ
Comment[pl]=Plazma dzięki KDE
Comment[pt]=Plasma do KDE
Comment[pt_BR]=Plasma do KDE
Comment[ru]=KDE Plasma
Comment[sk]=Plasma od KDE
Comment[sl]=KDE Plasma
Comment[sr]=Плазма од КДЕ‑а
Comment[sr@ijekavian]=Плазма од КДЕ‑а
Comment[sr@ijekavianlatin]=Plasma od KDE‑a
Comment[sr@latin]=Plasma od KDE‑a
Comment[sv]=Plasma av KDE
Comment[tr]=KDE Plasma
Comment[uk]=Плазма KDE
Comment[x-test]=xxPlasma by KDExx
Comment[zh_CN]=KDE 的 Plasma
Comment[zh_TW]=Plasma by KDE
X-KDE-PluginInfo-Version=${PROJECT_VERSION}
